<?xml version="1.0" encoding="utf-8" standalone="no"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">

<head>
  <title></title>
  <link href="../styles/style.css" rel="stylesheet" type="text/css"/>
</head>

<body>
  {% for item in content %}
  {{ item|safe }}
  {% endfor %}
  {% if citations %}
  <h2>{{ i18n.references }}</h2>
  {% for item in citations %}
  {{ item|safe }}
  {% endfor %}
  {% endif %}
</body>

</html>