<?xml version='1.0' encoding='utf-8'?>
<ncx xmlns="http://www.daisy.org/z3986/2005/ncx/" version="2005-1" xml:lang="zh">
  <head>
    <meta content="{{ depth }}" name="dtb:depth" />
    <meta content="0" name="dtb:totalPageCount" />
    <meta content="0" name="dtb:maxPageNumber" />
  </head>
  <docTitle>
{% if "title" in meta %}
    <text>{{ meta["title"] }}</text>
{% else %}
    <text>{{ i18n.unnamed }}</text>
{% endif %}
  </docTitle>
  <navMap>
{% if has_cover %}
    <navPoint id="cover" playOrder="0">
        <navLabel>
            <text>{{ i18n.cover }}</text>
        </navLabel>
        <content src="Text/cover.xhtml" />
    </navPoint>
{% endif %}
{% for nav_point in nav_points %}
    {{ nav_point|safe }}
{% endfor %}
  </navMap>
</ncx>