blockquote {
 	border-left: 0.15em solid #c7c7c7;
  margin: 0.75em;
  padding: 1em;
 	text-indent:2em;
  line-height:1.5em;
}

a.super {
	font-size: 0.75em;
	vertical-align: super;
}

a.citation {
	font-size: 0.75em;
  font-weight: bold;
	vertical-align: super;
  padding-right: 0.55em;
}

div.citation {
  margin-top: 0.5em;
  margin-left: 0.75em;
  margin-bottom: 1.5em;
}

div.alt-wrapper {
  display: flex;
  flex-direction: column;
  align-items: center;
  padding-top: 0.8em;
  padding-bottom: 3em;
}