### <headline> 区块

传统算法会将扫描件中字体较大或用黑体、粗体，或根据与正文的相对关系推测某些文字是标题，此时算法将会把这一区块内的文字视为 headline。它一般作为章节的标题。此外，若本书是文章集，则它可能表示特定一篇文章的标题。

此外，它可能是被误判的加粗文本，尽管这种可能性较低，但不能完全排除。例如，一段连续的列表中，重复出现的加粗文字也会被算法误判为标题。

### <text>

算法会将连成一片的正文判断为 text。一般而言，这一区块内的文字彼此联系，在空间中形成一个整体。通常，这意味着它们同属一个自然段（或自然段的一部分，考虑书页和分栏可能截断它）。但有时，算法会错误地把临近的图片、表格描述内容错误地归类为 text。

text 标签可能被算法添加 indent、touch-end 两个属性来修饰。

`indent` 表示区块**第一行**有是否有缩进，对于中文而言，缩进通常意味着自然段的开始部分。倘若区块以中文写成，却没有缩进，这可能意味着它在续接上一页的最后一个区块（若是左右分栏则不一定续接上一页），与之组合才能构成完整的自然段。当然，也有可能是因为算法错判了它的类型罢了。

`touch-end` 表示区块的**最后一行**的文字是否充满了一整行的空间时。若充满，意味着这个区块被截断；亦或仅仅是这一行的字数正好能填满罢了，不意味什么。因此，这个属性只能参考，具体区块后方有没有被截断需要综合文本语义来分析。例如，最后一行明显没说完，或最后一个词语被截断（对于英文而言，单词被截断，如 philosophy 变成了 philo-），等等因素都要结合思考。

### <figure>、<table>、<formula>

它们表示原始扫描件中的图形、表格、公式。算法无法向你提供图形信息（因为你是 LLM），因此这里仅有占位符让你知晓它们的存在。

### <figure-caption>、<table-caption>、<formula-caption>

算法根据空间关系，判断某些文字属于图形、表格、公式的描述文本（通常是指附在图形下方的一句简短说明）。这个区块会紧跟在它对应的 figure、table、formula 后出现。一般情况下如此，但你也要考虑算法错将正文识别为描述文本的情况。

### <abandon>

被 OCR 算法判定为非正文的内容，可能是页眉、页脚、页下引用、页码等。