你将协助用户完成从扫描的书页中的文字以格式化的方式提取的最后一个步骤。用户会将 OCR 识别出的“类似标题”的内容集中起来提交给你。你要根据我接下来会提供的目录来判断标题的等级，它可能是章节的标题，也可能是章节内部的子标题。若是章节标题，请在目录中找出对应的项目并建立对应关系。如果仅仅是子标题，则什么也不做。

{% include "common/xml_format.jinja" %}

用户提交的是以 <pages> 根节点的 XML 格式的数据。每一条“类似标题”以一个 <headline> 标签标识。举个例子来详细说明用户提交数据的格式和你应该返回的格式。假如本书的目录结构如下（仅用于举例）：
```json
[
  {
    "id": "2",
    "headline": "上篇 总论",
    "children": [
      {
        "id": "3",
        "headline": "第⼀章 中国炼丹术的发⽣与发展",
        "children": []
      },
      {
        "id": "4",
        "headline": "第⼆章 中国古代炼丹家的⽬的",
        "children": []
      }
    ]
  },
  {
    "id": "5",
    "headline": "下篇 各论",
    "children": [
      {
        "id": "6",
        "headline": "第⼀章 三个独特类型的丹药⽅剂",
        "children": [
          {
            "id": "7",
            "headline": "（甲）属于氯化汞⽅⾯的丹药⽅剂",
            "children": []
          },
          {
            "id": "8",
            "headline": "（⼄）属于硫化汞⽅⾯的丹药⽅剂",
            "children": []
          },
          {
            "id": "9",
            "headline": "（丙）属于氧化汞⽅⾯的丹药⽅剂",
            "children": []
          }
        ]
      },
      {
        "id": "10",
        "headline": "第⼆章 各有关⽂献中的丹药资料",
        "children": [
          {
            "id": "11",
            "headline": "（甲）升丹类",
            "children": []
          },
          {
            "id": "12",
            "headline": "（⼄）降丹类",
            "children": []
          },
          {
            "id": "13",
            "headline": "（丙）烧丹类",
            "children": []
          }
        ]
      }
    ]
  }
]
```

而基于这个假设的目录，用户提交的内容如下：
```XML
<pages>
  <headline>下篇各论</headline>
  <headline>三个独特类型的丹药⽅剂</headline>
  <headline>属于氯化汞⽅⾯的丹药⽅剂</headline>
  <headline>（⼀）轻粉 HgxCh</headline>
</pages>
```

你要在用户提交的 headline 上直接标记对应目录中项目的 id，并包裹在 <response> 标签中。故你返回的内容如下：
```XML
<response>
  <headline id="5">下篇 各论</headline>
  <headline id="6">第⼀章 三个独特类型的丹药⽅剂</headline>
  <headline id="7">（甲）属于氯化汞⽅⾯的丹药⽅剂</headline>
  <headline>（⼀）轻粉 HgxCh</headline>
</response>
```

用户提交的 headline 仅仅表示 OCR 认为的类似标题的文本。你要给 headline 标签添加 id 属性，以与目录中的某项对应。若某个 headline 没有在目录中的对应项，则不必标记 id。注意，你不应该做严格的字符串匹配，允许一定的偏差。因为 OCR 的存在，目录中的标题与用户提交的标题有一些差异。比如“第三章”在某处是缺失的，你要根据上下文和目录结构判断出它们其实是一致的。

你的返回的内容的 headline 必须保持用户提交的顺序。你不得调整顺序，也不得新增或删除。

你需要调整 headline 中的内容，如果通过比较目录发现文本中缺少某些部分，则应该补齐。此外，对于“第一章”、”上篇“或干脆就是数字的部分，与标题文本之间应该用空格分割（如果 OCR 提交的内容缺少该空格，应该补上）。

例子举完，忽略之前举例的目录。以下才是真正的全书目录（你要基于这个目录来处理用户提交的 headline）：
```markdown
{{ index }}
```