<?xml version="1.0" encoding="utf-8"?>
<package version="2.0" xmlns="http://www.idpf.org/2007/opf" unique-identifier="uid">
  <metadata xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:opf="http://www.idpf.org/2007/opf">
    <dc:language>zh</dc:language>
    <dc:identifier id="uid">{{ ISBN }}</dc:identifier>
{% if "title" in meta %}
    <dc:title>{{ meta["title"] }}</dc:title>
{% else %}
    <dc:title>{{ i18n.unnamed }}</dc:title>
{% endif %}
{% if "description" in meta %}
    <dc:description>{{ meta["description"] }}</dc:description>
{% endif %}
{% if "publisher" in meta %}
    <dc:publisher>{{ meta["publisher"] }}</dc:publisher>
{% endif %}
{% if "authors" in meta %}
{% for author in meta["authors"] %}
    <dc:creator opf:role="aut">{{ author }}</dc:creator>
{% endfor %}
{% endif %}
{% if "editors" in meta %}
{% for editor in meta["editors"] %}
    <dc:creator opf:role="edt">{{ editor }}</dc:creator>
{% endfor %}
{% endif %}
{% if "translators" in meta %}
{% for translator in meta["translators"] %}
    <dc:creator opf:role="trl">{{ translator }}</dc:creator>
{% endfor %}
{% endif %}
{% if has_cover %}
    <meta name="cover" content="a_cover" />
{% endif %}
    <meta name="output encoding" content="utf-8" />
    <meta name="primary-writing-mode" content="horizontal-lr" />
  </metadata>
  <manifest>
    <item id="a_css" media-type="text/css" href="styles/style.css" />
{% for asset_file in asset_files %}
    <item id="a_{{ asset_file }}" media-type="image/png" href="assets/{{ asset_file }}" />
{% endfor%}
{% if has_cover %}
    <item id="a_cover" media-type="image/png" href="assets/cover.png" />
    <item id="x_cover.xhtml" media-type="application/xhtml+xml" href="Text/cover.xhtml" />
{% endif %}
{% if has_head_chapter %}
    <item id="x_head.xhtml" media-type="application/xhtml+xml" href="Text/head.xhtml" />
{% endif %}
{% for nav_point in nav_points %}
    <item id="x_{{ nav_point.file_name }}" media-type="application/xhtml+xml" href="Text/{{ nav_point.file_name }}" />
{% endfor %}
{% if nav_points %}
    <item id="ncx" media-type="application/x-dtbncx+xml" href="toc.ncx" />
{% endif %}
  </manifest>
{% if nav_points %}
  <spine toc="ncx">
{% else %}
  <spine>
{% endif %}
{% if has_cover %}
    <itemref idref="x_cover.xhtml" linear="no" />
{% endif %}
{% if has_head_chapter %}
    <itemref idref="x_head.xhtml" />
{% endif %}
{% for nav_point in nav_points %}
    <itemref idref="x_{{ nav_point.file_name }}" />
{% endfor %}
  </spine>
</package>